@@ -14,6 +14,7 @@ import requests
 from dateutil.relativedelta import relativedelta  # 安装 pip install python-dateutil
 from retrying import retry
 
+
 def datetime_toString(dt: datetime) -> str:
     """
     把datetime转成字符串
@@ -22,6 +23,7 @@ def datetime_toString(dt: datetime) -> str:
     """
     return dt.strftime("%Y-%m-%d")
 
+
 def datetime_toString_detail(dt: datetime) -> str:
     """
     把datetime转成字符串 详细版
@@ -57,6 +59,7 @@ def timestamp_toString(stamp: int) -> str:
     """
     return time.strftime("%Y-%m-%d", time.localtime(stamp))
 
+
 def ts_toStr_det(stamp: int) -> str:
     """
     把时间戳转成字符串形式精确到秒
@@ -65,6 +68,7 @@ def ts_toStr_det(stamp: int) -> str:
     """
     return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(stamp))
 
+
 def datetime_toTimestamp(dateTime):
     """
     把datetime类型转外时间戳形式
@@ -74,6 +78,25 @@ def datetime_toTimestamp(dateTime):
     return int(time.mktime(dateTime.timetuple()))
 
 
+def string_totime_detail(str_p):
+    """2019-01-30 15:29:08"""
+    dateTime_p = datetime.datetime.strptime(str_p, '%Y-%m-%d %H:%M:%S')
+    return dateTime_p
+
+
+def substract_Time_detail(dateStr1: str, dateStr2: str) -> datetime:
+    """
+        返回两个日期之间的差
+        :param dateStr1:'2019-01-30 15:29:08'
+        :param dateStr2:'2019-01-30 15:29:08'
+        :return:<class 'datetime.timedelta'> 60 days, 0:00:00
+    """
+    str1 = string_totime_detail(dateStr1)
+    str2 = string_totime_detail(dateStr2)
+    difference = (str2 - str1)
+    return {'day': difference.days, 'min': difference.seconds / 60, 'seconds': difference.seconds}
+
+
 def substract_DateTime(dateStr1: str, dateStr2: str) -> datetime:
     """
     返回两个日期之间的差
@@ -149,35 +172,38 @@ def getBetweenDay(begin_date: str, end_date: str) -> list:
         begin_date += datetime.timedelta(days=1)
     return date_list
 
-def get_month_b_e_day(month = '202001'):
-        """传入月份返回当前月份的起始终止日期"""
-        year = month[0:4]
-        mon = month[4:]
-        mon = f'{int(mon) + 1}'
-        next_month = int(year+mon)
-        # print(next_month)
-        if (next_month % 100 == 13):
-            next_month = next_month - 12 + 100
-        month_end_day = (datetime.datetime(int(str(next_month)[0:4]), int(str(next_month)[4:6]), 1) - datetime.timedelta(days=1)).strftime("%Y-%m-%d")
-        month_begin_day = month_end_day.rsplit('-',1)[0]+'-01'
-        return month_begin_day, month_end_day
+
+def get_month_b_e_day(month='202001'):
+    """传入月份返回当前月份的起始终止日期"""
+    year = month[0:4]
+    mon = month[4:]
+    mon = f'{int(mon) + 1}'
+    next_month = int(year + mon)
+    # print(next_month)
+    if (next_month % 100 == 13):
+        next_month = next_month - 12 + 100
+    month_end_day = (datetime.datetime(int(str(next_month)[0:4]), int(str(next_month)[4:6]), 1) - datetime.timedelta(
+        days=1)).strftime("%Y-%m-%d")
+    month_begin_day = month_end_day.rsplit('-', 1)[0] + '-01'
+    return month_begin_day, month_end_day
+
 
 def month_datelist(start_day):
-        """
-        传入月份，会生成当前月份到传入月份之间的所有月份的开始终止日期
-        :param start_day:'2020-01'
-        :return:[['2020-01-01', '2020-01-31'], ['2020-02-01', '2020-02-29'], ['2020-03-01', '2020-03-31']]
-        """
-        start_day = datetime.datetime.strptime(start_day, r"%Y-%m")
-        end_day = datetime.datetime.now() - relativedelta(months=1)
-        months = (end_day.year - start_day.year) * 12 + end_day.month - start_day.month
-        month_range = ['%s%s' % (start_day.year + mon // 12, mon % 12 + 1)
-                       for mon in range(start_day.month - 1, start_day.month + months)]
-        month_list = []
-        for nonth in month_range:
-            month_begin_day, month_end_day = get_month_b_e_day(nonth)
-            month_list.append([month_begin_day, month_end_day])
-        return month_list
+    """
+    传入月份，会生成当前月份到传入月份之间的所有月份的开始终止日期
+    :param start_day:'2020-01'
+    :return:[['2020-01-01', '2020-01-31'], ['2020-02-01', '2020-02-29'], ['2020-03-01', '2020-03-31']]
+    """
+    start_day = datetime.datetime.strptime(start_day, r"%Y-%m")
+    end_day = datetime.datetime.now() - relativedelta(months=1)
+    months = (end_day.year - start_day.year) * 12 + end_day.month - start_day.month
+    month_range = ['%s%s' % (start_day.year + mon // 12, mon % 12 + 1)
+                   for mon in range(start_day.month - 1, start_day.month + months)]
+    month_list = []
+    for nonth in month_range:
+        month_begin_day, month_end_day = get_month_b_e_day(nonth)
+        month_list.append([month_begin_day, month_end_day])
+    return month_list
 
 
 def getdate(beforeOfDay):
@@ -193,6 +219,7 @@ def getdate(beforeOfDay):
     re_date = (today + offset).strftime('%Y-%m-%d')
     return re_date
 
+
 def getBeforeWeekDays(weeks=1):
     """
     获取前一周的所有日期(weeks=1)，获取前N周的所有日期(weeks=N)
@@ -210,6 +237,7 @@ def getBeforeWeekDays(weeks=1):
         days_list.append(day)
     return days_list
 
+
 def monitoring_run_time(f):
     """
     装饰器
@@ -217,14 +245,17 @@ def monitoring_run_time(f):
     :param f:
     :return:
     """
+
     def wrapper(*args, **kwargs):
         start_time = time.time()
         res = f(*args, **kwargs)
         end_time = time.time()
         print("%s执行成功，用时:%.2f" % (f.__name__, end_time - start_time))
         return res
+
     return wrapper
 
+
 @retry(stop_max_attempt_number=10)
 def get_taobao_time():
     """获取在线时间{"sysTime2":"2021-01-12 16:41:50","sysTime1":"20210112164150"}"""
@@ -247,7 +278,8 @@ def get_taobao_time():
                      "sysTime1": f"{datetime_toTimestamp(datetime.datetime.now())}"}
         return json_data
 
+
 if __name__ == '__main__':
     # month_begin_day = month_datelist('2020-01')
     # print(getdate(1))
-    print(get_taobao_time())
+    print(substract_Time_detail('2021-05-01 09:00:00', '2021-05-01 10:05:00'))
